# mzTab-M reference implementation and validation API.
# 
# This is the mzTab-M reference implementation and validation API service.
# 
# OpenAPI spec version: 2.0.0
# Contact: nils.hoffmann@isas.de
# Generated by: https://github.com/swagger-api/swagger-codegen.git


#' MsRun Class
#'
#' Specification of ms_run.  location: Location of the external data file e.g. raw files on which analysis has been performed. If the actual location of the MS run is unknown, a “null” MUST be used as a place holder value, since the [1-n] cardinality is referenced elsewhere. If pre-fractionation has been performed, then [1-n] ms_runs SHOULD be created per assay.  instrument_ref: If different instruments are used in different runs, instrument_ref can be used to link a specific instrument to a specific run.  format: Parameter specifying the data format of the external MS data file. If ms_run[1-n]-format is present, ms_run[1-n]-id_format SHOULD also be present, following the parameters specified in Table 1.  id_format: Parameter specifying the id format used in the external data file. If ms_run[1-n]-id_format is present, ms_run[1-n]-format SHOULD also be present. fragmentation_method: The type(s) of fragmentation used in a given ms run. scan_polarity: The polarity mode of a given run. Usually only one value SHOULD be given here except for the case of mixed polarity runs. hash: Hash value of the corresponding external MS data file defined in ms_run[1-n]-location. If ms_run[1-n]-hash is present, ms_run[1-n]-hash_method SHOULD also be present. hash_method: A parameter specifying the hash methods used to generate the String in ms_run[1-n]-hash. Specifics of the hash method used MAY follow the definitions of the mzML format. If ms_run[1-n]-hash is present, ms_run[1-n]-hash_method SHOULD also be present. 
#'
#' @field id 
#' @field elementType 
#' @field name 
#' @field location 
#' @field instrument_ref 
#' @field format 
#' @field id_format 
#' @field fragmentation_method 
#' @field scan_polarity 
#' @field hash 
#' @field hash_method 
#'
#' mzTab-M specification example(s)
#' \preformatted{
#' COM	location can be a local or remote URI
MTD	ms_run[1]-location	file:///C:/path/to/my/file.mzML
MTD	ms_run[1]-instrument_ref	instrument[1]
MTD	ms_run[1]-format	[MS, MS:1000584, mzML file, ]
MTD	ms_run[1]-id_format	[MS, MS:1000530, mzML unique identifier, ]
MTD	ms_run[1]-fragmentation_method[1]	[MS, MS:1000133, CID, ]
COM	for mixed polarity scan scenarios
MTD	ms_run[1]-scan_polarity[1]	[MS, MS:1000130, positive scan, ]
MTD	ms_run[1]-scan_polarity[2]	[MS, MS:1000129, negative scan, ]
MTD	ms_run[1]-hash_method	[MS, MS:1000569, SHA-1, ]
MTD	ms_run[1]-hash	de9f2c7fd25e1b3afad3e85a0bd17d9b100db4b3

#' }
#' 
#'
#' @importFrom R6 R6Class
#' @importFrom jsonlite fromJSON toJSON
#' @export
MsRun <- R6::R6Class(
  'MsRun',
  public = list(
    `id` = NULL,
    `elementType` = NULL,
    `name` = NULL,
    `location` = NULL,
    `instrument_ref` = NULL,
    `format` = NULL,
    `id_format` = NULL,
    `fragmentation_method` = NULL,
    `scan_polarity` = NULL,
    `hash` = NULL,
    `hash_method` = NULL,
    initialize = function(`id`, `elementType`, `name`, `location`, `instrument_ref`, `format`, `id_format`, `fragmentation_method`, `scan_polarity`, `hash`, `hash_method`){
      if (!missing(`id`)) {
        stopifnot(is.numeric(`id`), length(`id`) == 1)
        self$`id` <- `id`
      }
      if (!missing(`elementType`)) {
        stopifnot(is.character(`elementType`), length(`elementType`) == 1)
        self$`elementType` <- `elementType`
      }
      if (!missing(`name`)) {
        stopifnot(is.character(`name`), length(`name`) == 1)
        self$`name` <- `name`
      }
      if (!missing(`location`)) {
        stopifnot(is.character(`location`), length(`location`) == 1)
        self$`location` <- `location`
      }
      if (!missing(`instrument_ref`)) {
        stopifnot(R6::is.R6(`instrument_ref`))
        self$`instrument_ref` <- `instrument_ref`
      }
      if (!missing(`format`)) {
        stopifnot(R6::is.R6(`format`))
        self$`format` <- `format`
      }
      if (!missing(`id_format`)) {
        stopifnot(R6::is.R6(`id_format`))
        self$`id_format` <- `id_format`
      }
      if (!missing(`fragmentation_method`)) {
        stopifnot(is.list(`fragmentation_method`), length(`fragmentation_method`) != 0)
        lapply(`fragmentation_method`, function(x) stopifnot(R6::is.R6(x)))
        self$`fragmentation_method` <- `fragmentation_method`
      }
      if (!missing(`scan_polarity`)) {
        stopifnot(is.list(`scan_polarity`), length(`scan_polarity`) != 0)
        lapply(`scan_polarity`, function(x) stopifnot(R6::is.R6(x)))
        self$`scan_polarity` <- `scan_polarity`
      }
      if (!missing(`hash`)) {
        stopifnot(is.character(`hash`), length(`hash`) == 1)
        self$`hash` <- `hash`
      }
      if (!missing(`hash_method`)) {
        stopifnot(R6::is.R6(`hash_method`))
        self$`hash_method` <- `hash_method`
      }
    },
    toJSON = function() {
      MsRunObject <- list()
      if (!is.null(self$`id`)) {
        MsRunObject[['id']] <- self$`id`
      }
      if (!is.null(self$`elementType`)) {
        MsRunObject[['elementType']] <- self$`elementType`
      }
      if (!is.null(self$`name`)) {
        MsRunObject[['name']] <- self$`name`
      }
      if (!is.null(self$`location`)) {
        MsRunObject[['location']] <- self$`location`
      }
      if (!is.null(self$`instrument_ref`)) {
        MsRunObject[['instrument_ref']] <- self$`instrument_ref`$toJSON()
      }
      if (!is.null(self$`format`)) {
        MsRunObject[['format']] <- self$`format`$toJSON()
      }
      if (!is.null(self$`id_format`)) {
        MsRunObject[['id_format']] <- self$`id_format`$toJSON()
      }
      if (!is.null(self$`fragmentation_method`)) {
        MsRunObject[['fragmentation_method']] <- lapply(self$`fragmentation_method`, function(x) x$toJSON())
      }
      if (!is.null(self$`scan_polarity`)) {
        MsRunObject[['scan_polarity']] <- lapply(self$`scan_polarity`, function(x) x$toJSON())
      }
      if (!is.null(self$`hash`)) {
        MsRunObject[['hash']] <- self$`hash`
      }
      if (!is.null(self$`hash_method`)) {
        MsRunObject[['hash_method']] <- self$`hash_method`$toJSON()
      }

      MsRunObject
    },
    fromJSON = function(MsRunJson) {
      MsRunObject <- jsonlite::fromJSON(MsRunJson, simplifyVector = FALSE)
      if (!is.null(MsRunObject$`id`)) {
        self$`id` <- MsRunObject$`id`
      }
      if (!is.null(MsRunObject$`elementType`)) {
        self$`elementType` <- MsRunObject$`elementType`
      }
      if (!is.null(MsRunObject$`name`)) {
        self$`name` <- MsRunObject$`name`
      }
      if (!is.null(MsRunObject$`location`)) {
        self$`location` <- MsRunObject$`location`
      }
      if (!is.null(MsRunObject$`instrument_ref`)) {
        `instrument_refObject` <- Instrument$new()
        `instrument_refObject`$fromJSON(jsonlite::toJSON(MsRunObject$instrument_ref, auto_unbox = TRUE))
        self$`instrument_ref` <- `instrument_refObject`
      }
      if (!is.null(MsRunObject$`format`)) {
        `formatObject` <- Parameter$new()
        `formatObject`$fromJSON(jsonlite::toJSON(MsRunObject$format, auto_unbox = TRUE))
        self$`format` <- `formatObject`
      }
      if (!is.null(MsRunObject$`id_format`)) {
        `id_formatObject` <- Parameter$new()
        `id_formatObject`$fromJSON(jsonlite::toJSON(MsRunObject$id_format, auto_unbox = TRUE))
        self$`id_format` <- `id_formatObject`
      }
      if (!is.null(MsRunObject$`fragmentation_method`)) {
        self$`fragmentation_method` <- lapply(MsRunObject$`fragmentation_method`, function(x) {
          `fragmentation_methodObject` <- Parameter$new()
          `fragmentation_methodObject`$fromJSON(jsonlite::toJSON(x, auto_unbox = TRUE))
          `fragmentation_methodObject`
        })
      }
      if (!is.null(MsRunObject$`scan_polarity`)) {
        self$`scan_polarity` <- lapply(MsRunObject$`scan_polarity`, function(x) {
          `scan_polarityObject` <- Parameter$new()
          `scan_polarityObject`$fromJSON(jsonlite::toJSON(x, auto_unbox = TRUE))
          `scan_polarityObject`
        })
      }
      if (!is.null(MsRunObject$`hash`)) {
        self$`hash` <- MsRunObject$`hash`
      }
      if (!is.null(MsRunObject$`hash_method`)) {
        `hash_methodObject` <- Parameter$new()
        `hash_methodObject`$fromJSON(jsonlite::toJSON(MsRunObject$hash_method, auto_unbox = TRUE))
        self$`hash_method` <- `hash_methodObject`
      }
    },
    toJSONString = function() {
       sprintf(
        '{
           "id": %s,
           "elementType": %s,
           "name": %s,
           "location": %s,
           "instrument_ref": %s,
           "format": %s,
           "id_format": %s,
           "fragmentation_method": [%s],
           "scan_polarity": [%s],
           "hash": %s,
           "hash_method": %s
        }',
        self$`id`,
        self$`elementType`,
        self$`name`,
        self$`location`,
        self$`instrument_ref`$toJSON(),
        self$`format`$toJSON(),
        self$`id_format`$toJSON(),
        lapply(self$`fragmentation_method`, function(x) paste(x$toJSON(), sep=",")),
        lapply(self$`scan_polarity`, function(x) paste(x$toJSON(), sep=",")),
        self$`hash`,
        self$`hash_method`$toJSON()
      )
    },
    fromJSONString = function(MsRunJson) {
      MsRunObject <- jsonlite::fromJSON(MsRunJson, simplifyVector = FALSE)
      self$`id` <- MsRunObject$`id`
      self$`elementType` <- MsRunObject$`elementType`
      self$`name` <- MsRunObject$`name`
      self$`location` <- MsRunObject$`location`
      InstrumentObject <- Instrument$new()
      self$`instrument_ref` <- InstrumentObject$fromJSON(jsonlite::toJSON(MsRunObject$instrument_ref, auto_unbox = TRUE))
      ParameterObject <- Parameter$new()
      self$`format` <- ParameterObject$fromJSON(jsonlite::toJSON(MsRunObject$format, auto_unbox = TRUE))
      ParameterObject <- Parameter$new()
      self$`id_format` <- ParameterObject$fromJSON(jsonlite::toJSON(MsRunObject$id_format, auto_unbox = TRUE))
      self$`fragmentation_method` <- lapply(MsRunObject$`fragmentation_method`, function(x) Parameter$new()$fromJSON(jsonlite::toJSON(x, auto_unbox = TRUE)))
      self$`scan_polarity` <- lapply(MsRunObject$`scan_polarity`, function(x) Parameter$new()$fromJSON(jsonlite::toJSON(x, auto_unbox = TRUE)))
      self$`hash` <- MsRunObject$`hash`
      ParameterObject <- Parameter$new()
      self$`hash_method` <- ParameterObject$fromJSON(jsonlite::toJSON(MsRunObject$hash_method, auto_unbox = TRUE))
    }
  )
)
